@@ -1,7 +1,7 @@
 package HTML::Extract::CPANModules;
 
 our $DATE = '2016-02-21'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -78,7 +78,7 @@ sub extract_cpan_modules_from_html {
     }
 
     if ($args{from_text}) {
-        for my $el ($dom->find('p, td')->each) {
+        for my $el ($dom->find('*')->each) {
             my $text = $el->text;
             while ($text =~ /\b([A-Za-z_][A-Za-z_0-9]*(?:::[A-Za-z_0-9]+)+)\b/g) {
                 $mods{$1}++;
@@ -104,7 +104,7 @@ HTML::Extract::CPANModules - Extract CPAN module names from an HTML document
 
 =head1 VERSION
 
-This document describes version 0.02 of HTML::Extract::CPANModules (from Perl distribution HTML-Extract-CPANModules), released on 2016-02-21.
+This document describes version 0.03 of HTML::Extract::CPANModules (from Perl distribution HTML-Extract-CPANModules), released on 2016-02-21.
 
 =head1 FUNCTIONS
 
